==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/14/14ba607ddd642f82aef773ed8577b569.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/app/less/components/input-groups.less */
class __TwigTemplate_0c3df91ffab8d1e8a2cd5cd32722c0e7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "//
// Input groups
// --------------------------------------------------

// Base styles
// -------------------------
.input-group {
  .input-group-btn {
    + .form-control {
      margin-left: -1px;
    }
  }
}

.input-group-addon {
  border-width: var(--border-bottom);
  border-radius: var(--border-radius-sm);
  background-color: var(--field-hover);
  color: var(--text-secondary);
  border-color: var(--border-strong);
}

.table .input-group-sm {
  & > .input-group-addon {
    line-height: 1em;
    background-color: transparent;
    border: 0;
    padding: 0;
  }

  .dropdown-toggle {
    border: 0;
    background-color: transparent;
    padding: 5px 8px;
  }
}

.input-group {
  .input-group-btn {
    .btn.btn-ghost {
      height: 32px;
      width: 100%;
      background-color: var(--field);

      &:hover {
        background-color: var(--field-hover);
      }
    }

    &:last-child, &:only-of-type {
      .btn {border-radius: 0 var(--border-radius-sm) var(--border-radius-sm) 0;}
    }
    &:first-child {
      .btn {border-radius: var(--border-radius-sm) 0 0 var(--border-radius-sm);}
    }

    &:last-child {
      .btn {border-radius: 0 var(--border-radius-sm) var(--border-radius-sm) 0;}
    }
  }
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/app/less/components/input-groups.less";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/components/input-groups.less", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/css/app/less/components/input-groups.less");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/14/14ba607ddd642f82aef773ed8577b569.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/app/less/components/input-groups.less */
class __TwigTemplate_0c3df91ffab8d1e8a2cd5cd32722c0e7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "//
// Input groups
// --------------------------------------------------

// Base styles
// -------------------------
.input-group {
  .input-group-btn {
    + .form-control {
      margin-left: -1px;
    }
  }
}

.input-group-addon {
  border-width: var(--border-bottom);
  border-radius: var(--border-radius-sm);
  background-color: var(--field-hover);
  color: var(--text-secondary);
  border-color: var(--border-strong);
}

.table .input-group-sm {
  & > .input-group-addon {
    line-height: 1em;
    background-color: transparent;
    border: 0;
    padding: 0;
  }

  .dropdown-toggle {
    border: 0;
    background-color: transparent;
    padding: 5px 8px;
  }
}

.input-group {
  .input-group-btn {
    .btn.btn-ghost {
      height: 32px;
      width: 100%;
      background-color: var(--field);

      &:hover {
        background-color: var(--field-hover);
      }
    }

    &:last-child, &:only-of-type {
      .btn {border-radius: 0 var(--border-radius-sm) var(--border-radius-sm) 0;}
    }
    &:first-child {
      .btn {border-radius: var(--border-radius-sm) 0 0 var(--border-radius-sm);}
    }

    &:last-child {
      .btn {border-radius: 0 var(--border-radius-sm) var(--border-radius-sm) 0;}
    }
  }
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/app/less/components/input-groups.less";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/components/input-groups.less", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/app/less/components/input-groups.less");
    }
}
